==> igniteui-angular-charts-16.0.0.tgz: package/esm2015/lib/FinancialOverlay.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { FinancialSeries } from "./FinancialSeries";
import { DependencyProperty } from "igniteui-angular-core";
import { ISortingAxis_$type } from "./ISortingAxis";
import { typeCast, markType, markDep } from "igniteui-angular-core";
import { Rect } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { AxisRange } from "./AxisRange";
import { PropertyMetadata } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
export let FinancialOverlay = /*@__PURE__*/ (() => {
    class FinancialOverlay extends FinancialSeries {
        constructor() {
            super();
            this.tq = false;
            this.tq = false;
        }
        get_ds() {
            return true;
        }
        k3(a, b, c, d) {
            super.k3(a, b, c, d);
            if (this.qg != null && typeCast(ISortingAxis_$type, this.qg) !== null) {
                this.qg.i$i();
            }
            this.qx.bx.e(this.fv);
            this.tr();
            if (this.q2 != null) {
                this.q2.c0();
            }
            this.ml(true);
        }
        get_fa() {
            return true;
        }
        l7(a, b, c, d) {
            switch (b) {
                case "FastItemsSource":
                    this.tq = false;
                    break;
                case FinancialOverlay.$$p[0]:
                    this.tq = false;
                    this.ml(false);
                    this.ls();
                    break;
                case "XAxis":
                    this.tq = false;
                    break;
            }
            super.l7(a, b, c, d);
        }
        bp() {
            if (this.bq == 0) {
                return 1;
            }
            else {
                return super.bp();
            }
        }
        ex(a, b) {
            if (this.ew(a, b)) {
                return true;
            }
            return false;
        }
        ac() {
            super.ac();
            this.ml(false);
        }
        eo(a) {
            let b = this.ck != null ? this.ck.indexOf(a) : -1;
            let c = this.b0.bv;
            c = c.copy();
            let d = this.b0.bu;
            let e = new Rect(0, 0, 0, 1, 1);
            let f = this.px(this.b0);
            let g = new ScalerParams(0, e, e, this.qg.cg, f);
            let h = new ScalerParams(0, e, e, this.q2.cg, f);
            h.b = this.ge();
            if (b >= 0 && Rect.l_op_Inequality(c, null) && Rect.l_op_Inequality(d, null)) {
                if (this.qg != null) {
                    let i = this.qg.ei(b, g);
                    if (i < c.left + 0.1 * c.width) {
                        i = i + 0.4 * c.width;
                    }
                    if (i > c.right - 0.1 * c.width) {
                        i = i - 0.4 * c.width;
                    }
                    c.x = i - 0.5 * c.width;
                }
                if (this.q2 != null && this.rb != null && this.ra != null && b < this.rb.count && b < this.ra.count) {
                    let j = this.q2.ei(this.rb.item(b), h);
                    let k = this.q2.ei(this.ra.item(b), h);
                    if (!isNaN_(j) && !isNaN_(k)) {
                        let l = Math.abs(j - k);
                        if (c.height < l) {
                            c.height = l;
                            c.y = Math.min(j, k);
                        }
                        else {
                            if (j < c.top + 0.1 * c.height) {
                                j = j + 0.4 * c.height;
                            }
                            if (j > c.bottom - 0.1 * c.height) {
                                j = j - 0.4 * c.height;
                            }
                            c.y = j - 0.5 * c.height;
                        }
                    }
                }
                this.b8.au(this.cd, c, true);
            }
            return b >= 0;
        }
        ap(a) {
            if (a != null && a == this.q2 && this.rb != null && this.ra != null) {
                return new AxisRange(this.rb.minimum, this.ra.maximum);
            }
            return null;
        }
    }
    FinancialOverlay.$t = markType(FinancialOverlay, 'FinancialOverlay', FinancialSeries.$);
    FinancialOverlay.$$p = markDep(DependencyProperty, PropertyMetadata, FinancialOverlay, 'raisePropertyChanged', ['IgnoreFirst:ts:tu', [1, 0]]);
    return FinancialOverlay;
})();

==> igniteui-angular-charts-17.2.1.tgz: package/esm2015/lib/FinancialOverlay.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { FinancialSeries } from "./FinancialSeries";
import { DependencyProperty } from "igniteui-angular-core";
import { ISortingAxis_$type } from "./ISortingAxis";
import { typeCast, markType, markDep } from "igniteui-angular-core";
import { Rect } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { AxisRange } from "./AxisRange";
import { PropertyMetadata } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
export let FinancialOverlay = /*@__PURE__*/ (() => {
    class FinancialOverlay extends FinancialSeries {
        constructor() {
            super();
            this.x4 = false;
            this.x4 = false;
        }
        get_en() {
            return true;
        }
        np(a, b, c, d) {
            super.np(a, b, c, d);
            if (this.ua != null && typeCast(ISortingAxis_$type, this.ua) !== null) {
                this.ua.i$i();
            }
            this.ur.b0.e(this.hk);
            this.x5();
            if (this.uw != null) {
                this.uw.c1();
            }
            this.pq(true);
        }
        get_gl() {
            return true;
        }
        o9(a, b, c, d) {
            switch (b) {
                case "FastItemsSource":
                    this.x4 = false;
                    break;
                case FinancialOverlay.$$p[0]:
                    this.x4 = false;
                    this.pq(false);
                    this.om();
                    break;
                case "XAxis":
                    this.x4 = false;
                    break;
            }
            super.o9(a, b, c, d);
        }
        by() {
            if (this.bz == 0) {
                return 1;
            }
            else {
                return super.by();
            }
        }
        f5(a, b) {
            if (this.f4(a, b)) {
                return true;
            }
            return false;
        }
        ac() {
            super.ac();
            this.pq(false);
        }
        fp(a) {
            let b = this.c7 != null ? this.c7.indexOf(a) : -1;
            let c = this.ck.by;
            c = c.copy();
            let d = this.ck.bx;
            let e = new Rect(0, 0, 0, 1, 1);
            let f = this.tr(this.ck);
            let g = new ScalerParams(0, e, e, this.ua.ch, f);
            let h = new ScalerParams(0, e, e, this.uw.ch, f);
            h.b = this.h3();
            if (b >= 0 && Rect.l_op_Inequality(c, null) && Rect.l_op_Inequality(d, null)) {
                if (this.ua != null) {
                    let i = this.ua.ej(b, g);
                    if (i < c.left + 0.1 * c.width) {
                        i = i + 0.4 * c.width;
                    }
                    if (i > c.right - 0.1 * c.width) {
                        i = i - 0.4 * c.width;
                    }
                    c.x = i - 0.5 * c.width;
                }
                if (this.uw != null && this.u5 != null && this.u4 != null && b < this.u5.count && b < this.u4.count) {
                    let j = this.uw.ej(this.u5.item(b), h);
                    let k = this.uw.ej(this.u4.item(b), h);
                    if (!isNaN_(j) && !isNaN_(k)) {
                        let l = Math.abs(j - k);
                        if (c.height < l) {
                            c.height = l;
                            c.y = Math.min(j, k);
                        }
                        else {
                            if (j < c.top + 0.1 * c.height) {
                                j = j + 0.4 * c.height;
                            }
                            if (j > c.bottom - 0.1 * c.height) {
                                j = j - 0.4 * c.height;
                            }
                            c.y = j - 0.5 * c.height;
                        }
                    }
                }
                this.cs.au(this.cz, c, true);
            }
            return b >= 0;
        }
        aq(a) {
            if (a != null && a == this.uw && this.u5 != null && this.u4 != null) {
                return new AxisRange(this.u5.minimum, this.u4.maximum);
            }
            return null;
        }
    }
    FinancialOverlay.$t = markType(FinancialOverlay, 'FinancialOverlay', FinancialSeries.$);
    FinancialOverlay.$$p = markDep(DependencyProperty, PropertyMetadata, FinancialOverlay, 'raisePropertyChanged', ['IgnoreFirst:x6:x8', [1, 0]]);
    return FinancialOverlay;
})();
